@@ -4,10 +4,14 @@ use serde::{Deserialize, Serialize};
 #[serde(transparent)]
 pub struct PagingCursor(String);
 
-#[derive(Serialize, Debug, Eq, PartialEq, Default)]
+#[derive(Serialize, Debug, Eq, PartialEq, Default, Clone)]
 pub struct Paging {
     #[serde(skip_serializing_if = "Option::is_none")]
     pub start_cursor: Option<PagingCursor>,
     #[serde(skip_serializing_if = "Option::is_none")]
     pub page_size: Option<u8>,
 }
+
+pub trait Pageable {
+    fn start_from(self, starting_point: Paging) -> Self;
+}
