@@ -1,5 +1,6 @@
-use crate::models::paging::Paging;
-use crate::models::{Number, PageId, UserId};
+use crate::ids::{PageId, UserId};
+use crate::models::paging::{Pageable, Paging};
+use crate::models::Number;
 use chrono::{DateTime, Utc};
 use serde::ser::SerializeMap;
 use serde::{Serialize, Serializer};
@@ -281,13 +282,15 @@ pub struct DatabaseSort {
     // Todo: Should property and timestamp be mutually exclusive? (i.e a flattened enum?)
     //  the documentation is not clear:
     //  https://developers.notion.com/reference/post-database-query#post-database-query-sort
+    #[serde(skip_serializing_if = "Option::is_none")]
     pub property: Option<String>,
     /// The name of the timestamp to sort against.
+    #[serde(skip_serializing_if = "Option::is_none")]
     pub timestamp: Option<DatabaseSortTimestamp>,
     pub direction: SortDirection,
 }
 
-#[derive(Serialize, Debug, Eq, PartialEq, Default)]
+#[derive(Serialize, Debug, Eq, PartialEq, Default, Clone)]
 pub struct DatabaseQuery {
     #[serde(skip_serializing_if = "Option::is_none")]
     pub sorts: Option<Vec<DatabaseSort>>,
@@ -297,6 +300,15 @@ pub struct DatabaseQuery {
     pub paging: Option<Paging>,
 }
 
+impl Pageable for DatabaseQuery {
+    fn start_from(self, starting_point: Paging) -> Self {
+        DatabaseQuery {
+            paging: Some(starting_point),
+            ..self
+        }
+    }
+}
+
 #[derive(Debug, Eq, PartialEq)]
 pub enum NotionSearch {
     /// When supplied, limits which pages are returned by comparing the query to the page title.
